/* Laço -> for
 for(inicialização do contador; condição de parada; incrementa/decrementa a variável de inicialização)
 {
      declaração da lógica para execução no laço for;
 }

 Estrtura Seletiva -> if/else
 if(condição para execução)
 {
      declaração da lógica para execução no if;
 }
 else
 {
      declaração da lógica para execução no else;
 }

 ==========================================================================
 Posições dos valores do Vetor

 vetor[10]
 _______________________________________________________
 |           |           |           |     |           |
 | posição 0 | posição 1 | posição 2 | ... | posição 9 |
 |___________|___________|___________|_____|___________|

 ========================================================================== */


// Declaração das bibliotecas utilizadas
#include <stdio.h>
#include <stdlib.h>

// Definição de uma constante para determinar o tamanho do vetor.
// #Define é um pré-processador porque todas as constantes devem ser definidas antes do inicio do programa.
// Outro fato importante é que por padrão, sempre definimos nomes de constantes com letras maiúsculas.
#define TAMANHO_VETOR 10

// Função para geração de números aleatórios.
// Para a utilização da função rand() utiliza-se a biblioteca <stdlib.h>.
int numero_aleatorio(){
	return rand() % 100;
}

// Função para imprimir o maior valor do vetor.
void maior(int vetor[]){

    int i, x; // Declaração das variáveis.
    x = vetor[0]; // Variável x recebe o valor da primeira posição do vetor.

    for (i = 1; i < TAMANHO_VETOR; i++){ // Percorre desde a posição 2 até o final do vetor.
        if (vetor[i] > x){ // Compara se o valor da posição do vetor[i] é maior que o valor da variável x.
            x = vetor[i]; // Variável x recebe o valor do vetor referente a posição vetor[i].
        }
    }
    
    // Imprime o valor da variável x, x possui o maior valor do vetor.
    printf("O maior numero do vetor %d.\n\n\n", x);
}

// Função para imprimir o menor valor do vetor.
void menor(int vetor[]){
	
    int i, x;
    x = vetor[0];
 
    for (i = 1; i < TAMANHO_VETOR; i++){
        if (vetor[i] < x){ // Compara se o valor da posição do vetor[i] é menor que o valor da variável x.
            x = vetor[i]; // Variável x recebe o valor do vetor referente a posição vetor[i].
        }
    }
    
    // Imprime o valor da variável x, x possui o menor valor do vetor.
    printf("O menor numero do vetor %d.\n\n\n", x);
}

// Técnica para ordenação de vetor (Bubble Sort).
void ordena(int vetor[])
{
	int i, j, aux;

    // Realiza o laço for várias vezes, de acordo com o tamanho do vetor.
    for(i = TAMANHO_VETOR - 1; i >= 1; i--){
        for(j = 0; j < i; j++){
            // Verifica se o valor da posição vetor[j] é maior que valor da posição vetor[j + 1].
            if(vetor[j] > vetor[j + 1])
            {
                aux = vetor[j]; // Variável recebe valor da posição vetor[j] do vetor.
                vetor[j] = vetor[j + 1]; // Posição vetor[j] recebe valor da posição vetor[j + 1].
                vetor[j+1] = aux; // Posição vetor[j + 1] recebe valor da variável aux.
            }
        }
    }

    // Imprimi o vetor ordenado.
    printf("Vetor Ordenado\n");
    for (i = 0; i < TAMANHO_VETOR; i++){
        printf("%d\t", vetor[i]);
    }

    printf("\n\n\n");
}

int main(void)
{
    int i, vetor[TAMANHO_VETOR]; // Declaração das variáveis.
    
    // Laço for para preenchimento do vetor com números aleatórios.
    for (i = 0; i < TAMANHO_VETOR; i++){
        vetor[i] = numero_aleatorio(); // Variável vetor recebe o return da função números_aleatórios.
    }
    
    // Imprimi vetor original.
    printf("\n\nVetor Original\n");
    for (i = 0; i < TAMANHO_VETOR; i++){
        printf("%d\t", vetor[i]);
    }

    printf("\n\n");

    maior(vetor); // "chamar" função para imprimir o maior valor do vetor.
    menor(vetor); // "chamar" função para imprimir o menor valor do vetor.
    ordena(vetor); // "chamar" função para ordenadar e imprimir os valores do vetor.
	return 0;
 }
